Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(72)

Unified Diff: base/allocator/allocator_shim_override_glibc_weak_symbols.h

Issue 2393413003: Allocator shim explanatory error message. (Closed)
Patch Set: wording Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/allocator/allocator_shim_override_glibc_weak_symbols.h
diff --git a/base/allocator/allocator_shim_override_glibc_weak_symbols.h b/base/allocator/allocator_shim_override_glibc_weak_symbols.h
index dda49aa38354eb0e470aff44d8f80f1c340b8bae..7949399f2efa5763b0f6efbe4b01498a2c47e90d 100644
--- a/base/allocator/allocator_shim_override_glibc_weak_symbols.h
+++ b/base/allocator/allocator_shim_override_glibc_weak_symbols.h
@@ -105,5 +105,6 @@ SHIM_ALWAYS_EXPORT int __posix_memalign(void** r, size_t a, size_t s)
// Safety check.
#if !defined(__GLIBC__)
-#error The current platform does not seem to use Glibc.
+#error The target platform does not seem to use Glibc. Disable the allocator \
+shim by setting use_experimental_allocator_shim=false in GN args.
#endif
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698